@@ -16,7 +16,7 @@
 #'   \code{identity}. The discount function \code{scaledweibull} scales
 #'   the output of the Weibull CDF to have a max value of 1. The \code{identity}
 #'   discount function uses the posterior probability directly as the discount
-#'   weight. Default value is "\code{weibull}".
+#'   weight. Default value is "\code{identity}".
 #' @param alpha_max scalar. Maximum weight the discount function can apply.
 #'   Default is 1. For a two-arm trial, users may specify a vector of two values
 #'   where the first value is used to weight the historical treatment group and
@@ -27,20 +27,20 @@
 #'   value is 3. For a two-arm trial, users may specify a vector of two values
 #'   where the first value is used to estimate the weight of the historical
 #'   treatment group and the second value is used to estimate the weight of the
-#'   historical control group.
+#'   historical control group. Not used when \code{discount_function} = "identity".
 #' @param weibull_scale scalar. Scale parameter of the Weibull discount function
 #'   used to compute alpha, the weight parameter of the historical data. Default
 #'   value is 0.135. For a two-arm trial, users may specify a vector of two values
 #'   where the first value is used to estimate the weight of the historical
 #'   treatment group and the second value is used to estimate the weight of the
-#'   historical control group.
+#'   historical control group. Not used when \code{discount_function} = "identity".
 #' @param number_mcmc scalar. Number of Monte Carlo simulations. Default is 10000.
 #' @param a0 scalar. Prior value for the beta rate. Default is 1.
 #' @param b0 scalar. Prior value for the beta rate. Default is 1.
 #' @param method character. Analysis method with respect to estimation of the weight
-#'   paramter alpha. Default value "\code{fixed}" estimates alpha once and holds it fixed
-#'   throughout the analysis. Alternative method "\code{mc}" estimates alpha for each
-#'   Monte Carlo iteration. See the the \code{bdpbinomial} vignette \cr
+#'   paramter alpha. Default method "\code{mc}" estimates alpha for each
+#'   Monte Carlo iteration. Alternate value "\code{fixed}" estimates alpha once and
+#'   holds it fixed throughout the analysis. See the the \code{bdpbinomial} vignette \cr
 #'   \code{vignette("bdpbinomial-vignette", package="bayesDP")} for more details.
 #' @param compare logical. Should a comparison object be included in the fit?
 #'   For a one-arm analysis, the comparison object is simply the posterior
@@ -51,19 +51,17 @@
 #'   \code{TRUE}.
 #' @details \code{bdpbinomial} uses a two-stage approach for determining the
 #'   strength of historical data in estimation of a binomial count mean outcome.
-#'   In the first stage, a Weibull distribution function is used as a
-#'   \emph{discount function} that defines the maximum strength of the
-#'   historical data (via \code{weibull_shape}, \code{weibull_scale}, and
-#'   \code{alpha_max}) and discounts based on disagreement with the current data.
-#'   Disagreement between current and historical data is determined by stochastically
-#'   comparing the respective posterior distributions under noninformative priors.
-#'   With binomial data, the comparison is the proability (\code{p}) that the current
+#'   In the first stage, a \emph{discount function} is used that that defines the
+#'   maximum strength of the historical data and discounts based on disagreement with
+#'   the current data. Disagreement between current and historical data is determined by
+#'   stochastically comparing the respective posterior distributions under noninformative
+#'   priors. With binomial data, the comparison is the proability (\code{p}) that the current
 #'   count is less than the historical count. The comparison metric \code{p} is then
 #'   input into the Weibull discount function and the final strength of the
 #'   historical data is returned (alpha).
 #'
 #'  In the second stage, posterior estimation is performed where the discount
-#'  function parameter, \code{alpha}, is used as a fixed value for all posterior
+#'  function parameter, \code{alpha}, is used incorporated in all posterior
 #'  estimation procedures.
 #'
 #'  To carry out a single arm (OPC) analysis, data for the current treatment
@@ -153,10 +151,11 @@
 #'
 #' @examples
 #' # One-arm trial (OPC) example
-#' fit <- bdpbinomial(y_t           = 10,
-#'                    N_t           = 500,
-#'                    y0_t          = 25,
-#'                    N0_t          = 250)
+#' fit <- bdpbinomial(y_t    = 10,
+#'                    N_t    = 500,
+#'                    y0_t   = 25,
+#'                    N0_t   = 250,
+#'                    method = "fixed")
 #' summary(fit)
 #' print(fit)
 #' \dontrun{
@@ -164,14 +163,15 @@
 #' }
 #'
 #' # Two-arm (RCT) example
-#' fit2 <- bdpbinomial(y_t = 10,
-#'                     N_t = 500,
-#'                     y0_t = 25,
-#'                     N0_t = 250,
-#'                     y_c = 8,
-#'                     N_c = 500,
-#'                     y0_c = 20,
-#'                     N0_c = 250)
+#' fit2 <- bdpbinomial(y_t    = 10,
+#'                     N_t    = 500,
+#'                     y0_t   = 25,
+#'                     N0_t   = 250,
+#'                     y_c    = 8,
+#'                     N_c    = 500,
+#'                     y0_c   = 20,
+#'                     N0_c   = 250,
+#'                     method = "fixed")
 #' summary(fit2)
 #' print(fit2)
 #' \dontrun{
@@ -198,7 +198,7 @@ setGeneric("bdpbinomial",
                     N_c               = NULL,
                     y0_c              = NULL,
                     N0_c              = NULL,
-                    discount_function = "weibull",
+                    discount_function = "identity",
                     alpha_max         = 1,
                     fix_alpha         = FALSE,
                     a0                = 1,
@@ -206,7 +206,7 @@ setGeneric("bdpbinomial",
                     number_mcmc       = 10000,
                     weibull_scale     = 0.135,
                     weibull_shape     = 3,
-                    method            = "fixed",
+                    method            = "mc",
                     compare           = TRUE){
              standardGeneric("bdpbinomial")
            })
@@ -221,7 +221,7 @@ setMethod("bdpbinomial",
                    N_c               = NULL,
                    y0_c              = NULL,
                    N0_c              = NULL,
-                   discount_function = "weibull",
+                   discount_function = "identity",
                    alpha_max         = 1,
                    fix_alpha         = FALSE,
                    a0                = 1,
@@ -229,7 +229,7 @@ setMethod("bdpbinomial",
                    number_mcmc       = 10000,
                    weibull_scale     = 0.135,
                    weibull_shape     = 3,
-                   method            = "fixed",
+                   method            = "mc",
                    compare           = TRUE){
 
 
@@ -453,10 +453,13 @@ posterior_binomial <- function(y, N, y0, N0, discount_function,
     ### Test of model vs real
     if(method == "fixed"){
       p_hat <- mean(posterior_flat < prior)   # larger is higher failure
+      p_hat <- 2*ifelse(p_hat > 0.5, 1 - p_hat, p_hat)
     } else if(method == "mc"){
-      v     <- 1/((y + a0 - 1)/posterior_flat^2 + (N-y+b0-1)/(posterior_flat-1)^2)
-      v0    <- 1/((y0 + a0 - 1)/prior^2 + (N0-y0+b0-1)/(prior-1)^2)
-      Z     <- abs(posterior_flat-prior) / (v+v0)
+      # v     <- 1/((y + a0 - 1)/posterior_flat^2 + (N-y+b0-1)/(posterior_flat-1)^2)
+      # v0    <- 1/((y0 + a0 - 1)/prior^2 + (N0-y0+b0-1)/(prior-1)^2)
+      v     <- posterior_flat*(1-posterior_flat)/N
+      v0    <- prior*(1-prior)/N0
+      Z     <- abs(posterior_flat-prior) / sqrt(v+v0)
       p_hat <- 2*(1-pnorm(Z))
     }
 
@@ -465,7 +468,6 @@ posterior_binomial <- function(y, N, y0, N0, discount_function,
     if(fix_alpha == TRUE){
       alpha_discount <- alpha_max
     } else{
-        p_hat    <- 2*ifelse(p_hat > 0.5, 1 - p_hat, p_hat)
 
         # Compute alpha discount based on distribution
         if(discount_function == "weibull"){
@@ -478,7 +480,7 @@ posterior_binomial <- function(y, N, y0, N0, discount_function,
                                      scale=weibull_scale)*alpha_max/max_p
 
         } else if(discount_function == "identity"){
-          alpha_discount <- p_hat
+          alpha_discount <- p_hat*alpha_max
         }
 
     }
